"""
Class "Map". 「地图」类。
"""

from aviation_tools.airport import Airport
from aviation_tools.line import Line


class Map:
    """
    Map 地图
    """

    def __init__(self):
        self.points = set()
        self.routes = {}

    def add_airport(self, *airports):
        for airport in airports:
            assert type(airport) == str and len(airport) == 3
            self.points.add(airport)

    def add_route(self, *routes):
        for airport1, airport2 in routes:
            assert type(airport2) == str and len(airport2) == 3
            assert type(airport1) == str and len(airport1) == 3
            if airport2 < airport1:
                airport1, airport2 = airport2, airport1

            if airport1 not in self.routes:
                self.routes[airport1] = set()
            self.routes[airport1].add(airport2)

    @property
    def url(self):
        v = set(self.routes)
        for i in self.routes:
            v |= self.routes[i]
        s = list(self.points - v) + ["{}-{}".format(src, "/".join(self.routes[src]))
                                     for src in self.routes]
        return "https://gcmap.hanming.li/?query={}".format(",".join(s))


if __name__ == "__main__":
    p = Map()
    p.add_airport("SHA", "PEK", "CAN")
    p.add_route(("SHA", "CAN"), ("SHA", "PEK"))
    print(p.points)
    print(p.routes)
    print(p.url)
